@@ -35,7 +35,7 @@ from .verbose import verbose
 
 
 def bundle(wheel_path, qt_dir, build_tag_suffix, msvc_runtime, openssl,
-        openssl_dir, exclude):
+        openssl_dir, exclude, ignore_missing):
     """ Bundle a Qt installation with a PyQt wheel. """
 
     wheel_path = os.path.abspath(wheel_path)
@@ -120,7 +120,7 @@ def bundle(wheel_path, qt_dir, build_tag_suffix, msvc_runtime, openssl,
                         ignore_errors=True)
 
     # Bundle the relevant parts of the Qt installation.
-    package.bundle_qt(target_qt_dir, qt_dir, arch, exclude)
+    package.bundle_qt(target_qt_dir, qt_dir, arch, exclude, ignore_missing)
 
     if arch in ('win32', 'win_amd64'):
         # Bundle the MSVC runtime if required.
