@@ -27,10 +27,10 @@
 import os
 import sys
 
-from sipbuild import Option, Project
+from sipbuild import Option, Project, SIP_VERSION, UserException
 
 
-# The minimum GLIBC version required by Qt.  Strinctly speaking this should
+# The minimum GLIBC version required by Qt.  Strictly speaking this should
 # depend on the Qt version being used.
 MINIMUM_GLIBC_VERSION = '2.17'
 
@@ -54,9 +54,12 @@ class PyQtProject(Project):
             self.sip_files_dir = 'sip'
 
         if self.sip_module is None:
-            # TODO: don't hardcode PyQt5 (maybe something based on
-            # requires-dist)
-            self.sip_module = 'PyQt5.sip'
+            # It was a mistake to default to 'PyQt5.sip' rather than requiring
+            # it to be set explicitly.  We fix this for SIP v6.
+            if SIP_VERSION >= 0x060000:
+                raise UserException("'sip-module' must be set")
+            else:
+                self.sip_module = 'PyQt5.sip'
 
         # The tag prefix defaults to the meta-data name without any 'Py'
         # prefix.
@@ -150,6 +153,11 @@ class PyQtProject(Project):
 
         options = super().get_options()
 
+        # The directory containing the target Python interpreter library.
+        options.append(
+                Option('android_abis', option_type=list,
+                        help="the target Android ABI", metavar="ABI"))
+
         # The directory containing the target Python interpreter library.
         options.append(Option('py_pylib_dir'))
 
@@ -185,3 +193,28 @@ class PyQtProject(Project):
                 metavar="DIR", tools=['wheel']))
 
         return options
+
+    def update(self, tool):
+        """ Re-implemented to carry out any final updates to the configuration.
+        """
+
+        super().update(tool)
+
+        # Set the default minimum macOS version now that we should know the Qt
+        # version.  However, don't make any assumptions about the builder used.
+        if self.minimum_macos_version == '':
+            try:
+                qt_version = self.builder.qt_version
+            except AttributeError:
+                qt_version = 0
+
+            if qt_version >= 0x050e00:
+                self.minimum_macos_version = '10.13'
+            elif qt_version >= 0x050c00:
+                self.minimum_macos_version = '10.12'
+            elif qt_version >= 0x050a00:
+                self.minimum_macos_version = '10.11'
+            elif qt_version >= 0x050900:
+                self.minimum_macos_version = '10.10'
+            else:
+                self.minimum_macos_version = '10.9'
